@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008,2009,2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009,2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -13,11 +13,10 @@
 
 #include "kgpggeneratekey.h"
 
-#include <gpgproc.h>
-#include <kgpginterface.h>
+#include "gpgproc.h"
 
-#include <KMessageBox>
 #include <KLocale>
+#include <KMessageBox>
 #include <kpimutils/email.h>
 #include <QApplication>
 
@@ -273,3 +272,5 @@ KGpgGenerateKey::gpgErrorMessage() const
 {
 	return m_errorOutput;
 }
+
+#include "kgpggeneratekey.moc"
