@@ -61,8 +61,6 @@ public:
 
 	void write(const QByteArray &a);
 
-	static const QStringList &hintNames(void);
-
 private:
 	void processDone();
 
@@ -172,37 +170,8 @@ KGpgTransactionPrivate::slotReadReady()
 			}
 		} else if (line.startsWith(QLatin1String("[GNUPG:] CARDCTRL "))) {
 			// just ignore them, pinentry should handle that
-		} else {
-			// all known hints
-			int i = 0;
-			bool matched = false;
-			foreach (const QString &hintName, hintNames()) {
-				const KGpgTransaction::ts_hintType h = static_cast<KGpgTransaction::ts_hintType>(i++);
-				if (!line.startsWith(hintName))
-					continue;
-
-				matched = true;
-
-				bool r;
-				const int skip = hintName.length();
-				if (line.length() == skip) {
-					r = m_parent->hintLine(h, QString());
-				} else {
-					r = m_parent->hintLine(h, line.mid(skip + 1).trimmed());
-				}
-
-				if (!r) {
-					m_parent->setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
-					sendQuit();
-				}
-
-				break;
-			}
-
-			if (!matched) {
-				if (m_parent->nextLine(line))
-					sendQuit();
-			}
+		} else if (m_parent->nextLine(line)) {
+			sendQuit();
 		}
 	}
 }
@@ -281,19 +250,6 @@ KGpgTransactionPrivate::write(const QByteArray &a)
 #endif /* KGPG_DEBUG_TRANSACTIONS */
 }
 
-const QStringList &
-KGpgTransactionPrivate::hintNames (void)
-{
-	static QStringList hints;
-
-	if (hints.isEmpty()) {
-		hints.insert(KGpgTransaction::HT_KEYEXPIRED, QLatin1String("[GNUPG:] KEYEXPIRED"));
-		hints.insert(KGpgTransaction::HT_SIGEXPIRED, QLatin1String("[GNUPG:] SIGEXPIRED"));
-	}
-
-	return hints;
-}
-
 void
 KGpgTransactionPrivate::processDone()
 {
@@ -350,7 +306,7 @@ KGpgTransaction::askNewPassphrase(const QString& text)
 	d->m_passwordDialog->setAllowEmptyPasswords(false);
 	connect(d->m_passwordDialog, SIGNAL(newPassword(QString)), SLOT(slotPasswordEntered(QString)));
 	connect(d->m_passwordDialog, SIGNAL(rejected()), SLOT(slotPasswordAborted()));
-	connect(d->m_process, SIGNAL(processExited()), d->m_passwordDialog->button(KDialog::Cancel), SLOT(click()));
+	connect(d->m_process, SIGNAL(processExited()), d->m_passwordDialog->button(KDialog::Cancel), SLOT(clicked()));
 	d->m_passwordDialog->show();
 }
 
@@ -377,17 +333,6 @@ KGpgTransaction::boolQuestion(const QString& line)
 	return BA_UNKNOWN;
 }
 
-bool
-KGpgTransaction::hintLine(const ts_hintType hint, const QString &args)
-{
-	switch (hint) {
-	case HT_KEYEXPIRED:
-		return !args.isEmpty();
-	default:
-		return true;
-	}
-}
-
 void
 KGpgTransaction::finish()
 {
